Structs
- EnsName
Normalizer - Main struct to handle ENS name normalization including tokenization, validation, beautification and normalization
- Processed
Name - Result of processing an ENS name. Contains tokenized name as intermediate processing result and validated labels. Validated labels can be normalized and beautified.
- Token
Disallowed - Code point is disallowed
- Token
Emoji - Represents a vector of code points of emoji
cps_inputcontains vector of code from input stringemojicontains vector of beautified emoji code pointscps_no_fe0fcontains vector of code points of emoji withoutFE0F - Token
Ignored - Code point should be ignored
- Token
Mapped - Code point should be mapped to vector of code points
- Token
Nfc - Represents a vector of code points that should be normalized using NFC
- Token
Stop - Represents a stop token (.)
- Token
Valid - A valid vector of code points
- Tokenized
Label - Represents a tokenized ENS label (part of a name separated by periods), including sequence of tokens
- Tokenized
Name - Represents a full ENS name, including the original input and the sequence of tokens
- Validated
Label - Represents a validated ENS label as result of the
validate_labelfunction. Contains the original tokenized label and the type of the label.
Enums
- Collapsed
EnsName Token - Represents a collapsed token in an ENS name: either text or emoji
- Currable
Error - Errors that can be cured by the normalizer.
- Disallowed
Sequence - Errors regarding disallowed sequences.
- EnsName
Token - Represents a token in an ENS name. see https://docs.ens.domains/ensip/15#tokenize for more details.
- Process
Error - Errors that can occur during processing of an ENS name.
Functions
- beautify
no-cacheversion ofEnsNameNormalizer::beautify- normalize
no-cacheversion ofEnsNameNormalizer::normalize- process
no-cacheversion ofEnsNameNormalizer::process- tokenize
no-cacheversion ofEnsNameNormalizer::tokenize